==> img0ch-2.1.10.zip: img0ch/_template/default/i_threads.cs <==
<html>
<title><?cs var:html_escape(BBS_TITLE) ?></title>
<body
<?cs if:TextColor ?> text=#<?cs var:html_escape(TextColor) ?><?cs /if ?>
<?cs if:BackGroundColor ?> bgcolor=#<?cs var:html_escape(BackGroundColor) ?><?cs /if ?>
<?cs if:LinkColor ?> link=#<?cs var:html_escape(LinkColor) ?><?cs /if ?>
<?cs if:ALinkColor ?> alink=#<?cs var:html_escape(ALinkColor) ?><?cs /if ?>
<?cs if:VLinkColor ?> vlink=#<?cs var:html_escape(VLinkColor) ?><?cs /if ?>
>
<?cs if:Fontsize ?><font size=<?cs var:html_escape(Fontsize) ?>><?cs /if ?>
<?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>
<?cs if:Write ?>
<form method=post action=<?cs var:html_escape(CGIURI) ?>/bbs.cgi utn>
<input name=subject size=14><br>
<input name=FROM size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(NameByCookie) ?><?cs /if ?>><br>
<input name=mail size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(MailByCookie) ?><?cs /if ?>><br>
<textarea name=MESSAGE></textarea><br>
<input type=submit value= accesskey=4>
<input type=hidden name=bbs value=<?cs var:html_escape(BBS) ?>>
<input type=hidden name=time value=<?cs var:html_escape(TimeStamp) ?>>
<input type=hidden name=get value=1>
<input type=hidden name=submit value=>
</form>
<hr><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/i
<?cs else ?>i<?cs /if ?>></a>
<?cs else ?>
<a name=u></a>
<form action=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/i
<?cs else ?>i<?cs /if ?> method=post><input name=s size=11>
<input type=submit value=>
<a href=#b accesskey=8></a>
</form>
<?cs if:Copy ?>
<form action=c>
<textarea><?cs var:html_escape(Title) ?><?cs var:html_escape(CR) ?><?cs var:html_escape(BBSURI) ?></textarea><hr>
<?cs each:item = Threads ?>
<textarea><?cs var:html_escape(item.index) ?>:<?cs var:item.subject ?>  (<?cs var:html_escape(item.res) ?>)
<?cs var:html_escape(CR) ?>
<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/
</textarea><br><?cs /each ?></form>
<?cs else ?>
<?cs var:html_escape(Title) ?><hr>
<?cs each:item = Threads ?>
<?cs var:html_escape(item.index) ?>:<a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/!<?cs var:html_escape(QueryString) ?>
<?cs else ?><?cs var:html_escape(item.key) ?><?cs /if ?>/i>
<?cs var:item.subject ?>  (<?cs var:html_escape(item.res) ?>)</a><br>
<?cs /each ?>
<?cs if:Search ?><?cs var:html_escape(Count) ?> thread hit!<?cs /if ?>
<?cs /if ?>
<hr>
<a name=b></a>
<a href=#u accesskey=2></a>
<?cs if:Prev ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Prev) ?>
<?cs else ?><?cs var:html_escape(Prev) ?><?cs /if ?> accesskey=7>O</a><?cs /if ?>
<?cs if:Count ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Next) ?>
<?cs else ?><?cs var:html_escape(Next) ?><?cs /if ?> accesskey=9></a><?cs /if ?>
<?cs if:Count ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(From) ?>
<?cs else ?><?cs var:html_escape(From) ?><?cs /if ?> accesskey=1><?cs var:html_escape(From) ?>-</a>
<?cs else ?><a href=1 accesskey=3>V</a><?cs /if ?>
<a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/w
<?cs else ?>w<?cs /if ?> accesskey=4></a>
<?cs if:Copy ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Prev) ?>
<?cs else ?><?cs var:html_escape(Prev) ?><?cs /if ?> accesskey=5></a>
<?cs else ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Current) ?>c
<?cs else ?><?cs var:html_escape(Current) ?>c<?cs /if ?> accesskey=5></a><?cs /if ?>
<a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/!<?cs var:html_escape(QueryString) ?>/
<?cs else ?>.<?cs /if ?> accesskey=6></a>
<?cs /if ?>
</body>
</html>

==> img0ch-2.1.11.zip: img0ch/_template/default/i_threads.cs <==
<html>
<head>
<title><?cs var:html_escape(BBS_TITLE) ?></title>
<meta http-equiv=Content-Type content="text/html;charset=sjis">
</head>
<body
<?cs if:TextColor ?> text=#<?cs var:html_escape(TextColor) ?><?cs /if ?>
<?cs if:BackGroundColor ?> bgcolor=#<?cs var:html_escape(BackGroundColor) ?><?cs /if ?>
<?cs if:LinkColor ?> link=#<?cs var:html_escape(LinkColor) ?><?cs /if ?>
<?cs if:ALinkColor ?> alink=#<?cs var:html_escape(ALinkColor) ?><?cs /if ?>
<?cs if:VLinkColor ?> vlink=#<?cs var:html_escape(VLinkColor) ?><?cs /if ?>
>
<?cs if:Fontsize ?><font size=<?cs var:html_escape(Fontsize) ?>><?cs /if ?>
<?cs if:Banner ?><?cs var:Banner ?><hr><?cs /if ?>
<?cs if:Write ?>
<form method=post action=<?cs var:html_escape(CGIURI) ?>/bbs.cgi utn>
<input name=subject size=14><br>
<input name=FROM size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(NameByCookie) ?><?cs /if ?>><br>
<input name=mail size=14<?cs if:NameByCookie ?> value=<?cs var:html_escape(MailByCookie) ?><?cs /if ?>><br>
<textarea name=MESSAGE></textarea><br>
<input type=submit value= accesskey=4>
<input type=hidden name=bbs value=<?cs var:html_escape(BBS) ?>>
<input type=hidden name=time value=<?cs var:html_escape(TimeStamp) ?>>
<input type=hidden name=get value=1>
<input type=hidden name=submit value=>
</form>
<hr><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/i
<?cs else ?>i<?cs /if ?>></a>
<?cs else ?>
<a name=u></a>
<form action=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/i
<?cs else ?>i<?cs /if ?> method=post><input name=s size=11>
<input type=submit value=>
<a href=#b accesskey=8></a>
</form>
<?cs if:Copy ?>
<form action=c>
<textarea><?cs var:html_escape(Title) ?><?cs var:html_escape(CR) ?><?cs var:html_escape(BBSURI) ?></textarea><hr>
<?cs each:item = Threads ?>
<textarea><?cs var:html_escape(item.index) ?>:<?cs var:item.subject ?>  (<?cs var:html_escape(item.res) ?>)
<?cs var:html_escape(CR) ?>
<?cs var:html_escape(CGIURI) ?>/read.cgi/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/
</textarea><br><?cs /each ?></form>
<?cs else ?>
<?cs var:html_escape(Title) ?><hr>
<?cs each:item = Threads ?>
<?cs var:html_escape(item.index) ?>:<a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(item.key) ?>/<?cs var:html_escape(QueryString) ?>
<?cs else ?><?cs var:html_escape(item.key) ?><?cs /if ?>/i>
<?cs var:item.subject ?>  (<?cs var:html_escape(item.res) ?>)</a><br>
<?cs /each ?>
<?cs if:Search ?><?cs var:html_escape(Count) ?> thread hit<?cs /if ?>
<?cs /if ?>
<hr>
<a name=b></a>
<a href=#u accesskey=2></a>
<?cs if:Prev ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Prev) ?>
<?cs else ?><?cs var:html_escape(Prev) ?><?cs /if ?> accesskey=7>O</a><?cs /if ?>
<?cs if:Count ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Next) ?>
<?cs else ?><?cs var:html_escape(Next) ?><?cs /if ?> accesskey=9></a><?cs /if ?>
<?cs if:Count ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(From) ?>
<?cs else ?><?cs var:html_escape(From) ?><?cs /if ?> accesskey=1><?cs var:html_escape(From) ?>-</a>
<?cs else ?><a href=1 accesskey=3>V</a><?cs /if ?>
<a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/w
<?cs else ?>w<?cs /if ?> accesskey=4></a>
<?cs if:Copy ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Prev) ?>
<?cs else ?><?cs var:html_escape(Prev) ?><?cs /if ?> accesskey=5></a>
<?cs else ?><a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/<?cs var:html_escape(Current) ?>c
<?cs else ?><?cs var:html_escape(Current) ?>c<?cs /if ?> accesskey=5></a><?cs /if ?>
<a href=<?cs if:QueryString ?>
<?cs var:html_escape(RCGIURI) ?>/<?cs var:html_escape(BBS) ?>/<?cs var:html_escape(QueryString) ?>/
<?cs else ?>.<?cs /if ?> accesskey=6></a>
<a href=<?cs var:html_escape(CGIURI) ?>/img0ch-st.cgi/<?cs var:html_escape(BBS) ?>/?m=1></a>
<?cs if:BBS_ACCEPT_MAILPOST ?>
<a href=<?cs var:html_escape(CGIURI) ?>/m.cgi/<?cs var:html_escape(BBS) ?>/>X</a>
<?cs /if ?>
<?cs /if ?>
</body>
</html>
